@@ -1,3 +1,5 @@
+#include <chrono>
+#include <cstddef>
 #include <gtest/gtest.h>
 
 #include <array>
@@ -5,8 +7,9 @@
 #include <fstream>
 #include <string>
 
-#include <cpr/cpr.h>
-#include <cpr/multipart.h>
+#include "cpr/cookies.h"
+#include "cpr/cpr.h"
+#include "cpr/multipart.h"
 
 #include "httpServer.hpp"
 
@@ -116,7 +119,7 @@ TEST(UrlEncodedPostTests, UrlPostBadHostTest) {
     EXPECT_EQ(url, response.url);
     EXPECT_EQ(std::string{}, response.header["content-type"]);
     EXPECT_EQ(0, response.status_code);
-    EXPECT_EQ(ErrorCode::HOST_RESOLUTION_FAILURE, response.error.code);
+    EXPECT_EQ(ErrorCode::COULDNT_RESOLVE_HOST, response.error.code);
 }
 
 TEST(UrlEncodedPostTests, FormPostSingleTest) {
@@ -630,10 +633,17 @@ TEST(UrlEncodedPostTests, PostWithNoBodyTest) {
 }
 
 static std::string getTimestamp() {
-    char buf[1000];
-    time_t now = time(0);
-    struct tm* tm = gmtime(&now);
-    strftime(buf, sizeof buf, "%a, %d %b %Y %H:%M:%S GMT", tm);
+    const std::chrono::system_clock::time_point tp = std::chrono::system_clock::now();
+    const time_t timeT = std::chrono::system_clock::to_time_t(tp);
+    // NOLINTNEXTLINE(concurrency-mt-unsafe)
+    struct tm* tm = gmtime(&timeT);
+
+    std::string buf;
+    buf.resize(EXPIRES_STRING_SIZE);
+
+    const size_t s = strftime(buf.data(), buf.size(), "%a, %d %b %Y %H:%M:%S GMT", tm);
+    EXPECT_GT(s, 0);
+    buf.resize(s);
     return buf;
 }
 
